#!/bin/bash
#
# VERSION=23
# CHANGES="changed to be just a starter-script for /usr/sbin/install_daemon.sh"
#

# constants #
PIDFILE=/var/run/install_daemon.pid
PIPEFILE=/tmp/install_pipe

if [ -z "${1}" ]; then
	echo "ERROR: No Package specified, leaving."
	exit 1
fi

# check if there is a PIDFILE
if [ -f ${PIDFILE} ]; then
	echo "ERROR: An Installation-Process seems to be running already, leaving."
	exit 2
fi

#check if we need to make a downgrade
cd /tmp && tar zxf /mnt/images/${1} VERSION
cat VERSION|grep 'APPFS=3$' &> /dev/null
if [[  $? = 0 && -f /usr/local/downgrade-builtin.tar.gz ]]; then
	#we allow installing FW 16.11 to 16.19
	echo $1 |grep 'appfs-16.1[1-9]' &> /dev/null
	if [ $? = 0 ]; then
		rm /tmp/VERSION
		echo Preparing downgrading to $1
		cp /usr/local/downgrade-builtin.tar.gz /mnt/images/
		/usr/fallback/install.sh downgrade-builtin.tar.gz
		touch /tmp/DOWNGRADED
	else
		echo Cannot downgrade to $1
	fi
fi

# create named pipe to catch output
rm -f ${PIPEFILE}
/bin/mknod ${PIPEFILE} p

/sbin/start-stop-daemon -S -b -m -p ${PIDFILE} -x /usr/sbin/install_daemon.sh -- ${1}
sleep 2

while true; do
	if [ ! -f ${PIDFILE} ]; then
		killall -3 tail
		break
	fi
	sleep 2
done &

tail -f ${PIPEFILE}

sleep 1
rm -f ${PIPEFILE}

#delete the install package
if [ -f /mnt/images/"$1" ]; then
	rm /mnt/images/"$1"
fi

exit 0
